@@ -29,7 +29,9 @@ eudract_convert <- function(input, output,
   xml2::write_xml(output_xml, output)
   message(paste0("'",output, "' is created or modified\n"))
   #check against the output schema
-  check_out <- ( Sys.info()["sysname"]=="Windows") || xml2::xml_validate(output_xml, schema_output) #
+  check_out <- ( Sys.info()["sysname"]=="Windows") || 
+    ( Sys.info()["sysname"]=="Darwin") ||
+    xml2::xml_validate(output_xml, schema_output) #
   if( !check_out){ warning(attr(check_out,"errors"))}
   message("Please email cuh.cctu@nhs.net to tell us if you have successfully uploaded a study to EudraCT.\nThis is to allow us to measure the impact of this tool.")
   invisible(check_out)
